Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 118 variants ClaimMissing { label: String, }, AssertionUnsupportedVersion, AssertionMissing { url: String, }, AssertionEncoding(String), AssertionDecoding(AssertionDecodeError), AssertionInvalidRedaction, AssertionRedactionNotFound, AssertionSpecificError(String), BadParam(String), MissingFeature(String), ValidationRule(String), NotImplemented(String), ClaimEncoding, ClaimDecoding(String), ClaimAlreadySigned, ClaimUnsigned, ClaimMissingSignatureBox, ClaimMissingIdentity, ClaimVersion, ClaimInvalidContent, ClaimMissingHardBinding, ClaimMultipleHardBinding, ClaimSelfRedact, ClaimDisallowedRedaction, UpdateManifestInvalid, TooManyManifestStores, UnreferencedManifest, InvalidCoseSignature { coset_error: CoseError, }, CoseSignatureAlgorithmNotSupported, CoseMissingKey, CoseX5ChainMissing, CoseInvalidCert, CoseSignature, CoseVerifier, CoseCertExpiration, CoseCertRevoked, CoseCertUntrusted, CoseInvalidTimeStamp, CoseTimeStampValidity, CoseTimeStampMismatch, CoseTimeStampGeneration, CoseTimeStampAuthority, CoseSigboxTooSmall, CoseNoCerts, WasmVerifier, WasmRsaKeyImport(String), WasmRsaVerification, WasmKey, WasmInvalidContext, WasmNoCrypto, WasmNoRemoteSigner, WasmFeatureUnsupported, JumbfCreationError, ThreadReceiveError, JumbfNotFound, JumbfBoxNotFound, RemoteManifestFetch(String), RemoteManifestUrl(String), FailedToFetchSettings, FailedToRemoteSign, LogStop, NotFound, UnsupportedType, UnsupportedThumbnailFormat(String), MissingSignerSettings, MissingAutoCreatedActionSourceType, EmbeddingError, IngredientNotFound, FileNotFound(String), ResourceNotFound(String), XmpReadError(String), XmpWriteError(String), XmpNotSupported, ProvenanceMissing, HashMismatch(String), CyclicIngredients { claim_label_path: Vec<String>, }, ClaimVerification(String), PdfReadError, InvalidClaim(InvalidClaimError), InvalidAsset(String), JumbfParseError(JumbfParseError), VerifiableCredentialInvalid, InvalidEcdsaSignature, MissingDataBox, XmlWriteError, UnknownAlgorithm, InvalidSigningKey, Utf8Error(Utf8Error), HttpError(Error), HttpResolverError(HttpResolverError), TryFromIntError(TryFromIntError), IoError(Error), JsonError(Error), ImageError(ImageError), CborError(Error), TomlSerializationError(Error), OtherError(Box<dyn Error + Send + Sync>), PrereleaseError, VersionCompatibility(String), InsufficientMemory, OutOfRange, TimeStampError(TimeStampError), RawSignatureValidationError(RawSignatureValidationError), RawSignerError(RawSignerError), CertificateProfileError(CertificateProfileError), CertificateTrustError(CertificateTrustError), InvalidCertificateError(InvalidCertificateError), InternalError(String), C2PAValidation(String), BmffError(BmffError), GifError(GifError), JpegError(JpegError), Mp3Error(Mp3Error), PdfError(PdfError), PngError(PngError), RiffError(RiffError), SvgError(SvgError), TiffError(TiffError),
}
Error enumerates errors returned by most C2PA toolkit operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ClaimMissing

Could not find a claim with this label.

Fields

label: String


AssertionUnsupportedVersion

An assertion has an unsupported version



AssertionMissing

An assertion could not be found at the expected URL.

Fields



AssertionEncoding(String)

The attempt to serialize the assertion (typically to JSON or CBOR) failed.



AssertionDecoding(AssertionDecodeError)



AssertionInvalidRedaction



AssertionRedactionNotFound



AssertionSpecificError(String)



BadParam(String)



MissingFeature(String)



ValidationRule(String)



NotImplemented(String)



ClaimEncoding

The attempt to serialize the claim to CBOR failed.



ClaimDecoding(String)

The attempt to deserialize the claim from CBOR failed.



ClaimAlreadySigned



ClaimUnsigned



ClaimMissingSignatureBox



ClaimMissingIdentity



ClaimVersion



ClaimInvalidContent



ClaimMissingHardBinding



ClaimMultipleHardBinding



ClaimSelfRedact



ClaimDisallowedRedaction



UpdateManifestInvalid



TooManyManifestStores



UnreferencedManifest



InvalidCoseSignature

The COSE Sign1 structure can not be parsed.

Fields

coset_error: CoseError


CoseSignatureAlgorithmNotSupported

The COSE signature uses an algorithm that is not supported by this crate.



CoseMissingKey



CoseX5ChainMissing

The COSE signature did not contain a signing certificate.



CoseInvalidCert



CoseSignature



CoseVerifier



CoseCertExpiration



CoseCertRevoked



CoseCertUntrusted



CoseInvalidTimeStamp

Unable to parse the time stamp from this signature.



CoseTimeStampValidity



CoseTimeStampMismatch

The time stamp in the signature did not match the signed data.



CoseTimeStampGeneration

Unable to generate a trusted time stamp.



CoseTimeStampAuthority



CoseSigboxTooSmall



CoseNoCerts



WasmVerifier



WasmRsaKeyImport(String)



WasmRsaVerification



WasmKey



WasmInvalidContext



WasmNoCrypto



WasmNoRemoteSigner



WasmFeatureUnsupported



JumbfCreationError

Unable to generate valid JUMBF for a claim.



ThreadReceiveError



JumbfNotFound



JumbfBoxNotFound



RemoteManifestFetch(String)



RemoteManifestUrl(String)



FailedToFetchSettings



FailedToRemoteSign



LogStop



NotFound



UnsupportedType



UnsupportedThumbnailFormat(String)



MissingSignerSettings



MissingAutoCreatedActionSourceType



EmbeddingError



IngredientNotFound



FileNotFound(String)



ResourceNotFound(String)



XmpReadError(String)



XmpWriteError(String)



XmpNotSupported



ProvenanceMissing



HashMismatch(String)



CyclicIngredients

Fields

claim_label_path: Vec<String>


ClaimVerification(String)



PdfReadError



InvalidClaim(InvalidClaimError)



InvalidAsset(String)



JumbfParseError(JumbfParseError)



VerifiableCredentialInvalid



InvalidEcdsaSignature

Could not parse ECDSA signature. (Only appears when using WASM web crypto.)



MissingDataBox



XmlWriteError



UnknownAlgorithm



InvalidSigningKey



Utf8Error(Utf8Error)



HttpError(Error)



HttpResolverError(HttpResolverError)



TryFromIntError(TryFromIntError)



IoError(Error)



JsonError(Error)



ImageError(ImageError)



CborError(Error)



TomlSerializationError(Error)



OtherError(Box<dyn Error + Send + Sync>)



PrereleaseError



VersionCompatibility(String)



InsufficientMemory



OutOfRange



TimeStampError(TimeStampError)



RawSignatureValidationError(RawSignatureValidationError)



RawSignerError(RawSignerError)



CertificateProfileError(CertificateProfileError)



CertificateTrustError(CertificateTrustError)



InvalidCertificateError(InvalidCertificateError)



InternalError(String)

An unexpected internal error occured while requesting the time stamp response.



C2PAValidation(String)



BmffError(BmffError)



GifError(GifError)



JpegError(JpegError)



Mp3Error(Mp3Error)



PdfError(PdfError)



PngError(PngError)



RiffError(RiffError)



SvgError(SvgError)



TiffError(TiffError)